# Examples

Please contribute your examples, submit a pull request!

## Turn restrictions as a list

File: `turn_restriction_relations_as_list.py`

This example requests a CSV response from an Overpass query for turn restrictions within the Toronto city limits.

The result is then converted to a Python list and printed to stdout.

Sample output:

```python
['6809605', 'hoream_telenav', '2016-12-21T15:05:42Z', '', 'no_left_turn'], 
...
```

